@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -23,6 +23,7 @@ from tencentcloud.ckafka.v20190819 import models
 class CkafkaClient(AbstractClient):
     _apiVersion = '2019-08-19'
     _endpoint = 'ckafka.tencentcloudapi.com'
+    _service = 'ckafka'
 
 
     def CreateAcl(self, request):
@@ -221,6 +222,34 @@ class CkafkaClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DeleteAclRule(self, request):
+        """删除ACL规则
+
+        :param request: Request instance for DeleteAclRule.
+        :type request: :class:`tencentcloud.ckafka.v20190819.models.DeleteAclRuleRequest`
+        :rtype: :class:`tencentcloud.ckafka.v20190819.models.DeleteAclRuleResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DeleteAclRule", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DeleteAclRuleResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DeleteTopic(self, request):
         """删除ckafka主题
 
@@ -361,6 +390,34 @@ class CkafkaClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeCkafkaZone(self, request):
+        """用于查看ckafka的可用区列表
+
+        :param request: Request instance for DescribeCkafkaZone.
+        :type request: :class:`tencentcloud.ckafka.v20190819.models.DescribeCkafkaZoneRequest`
+        :rtype: :class:`tencentcloud.ckafka.v20190819.models.DescribeCkafkaZoneResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeCkafkaZone", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeCkafkaZoneResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeConsumerGroup(self, request):
         """查询消费分组信息
 
@@ -557,6 +614,34 @@ class CkafkaClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeRegion(self, request):
+        """枚举地域,只支持广州地域
+
+        :param request: Request instance for DescribeRegion.
+        :type request: :class:`tencentcloud.ckafka.v20190819.models.DescribeRegionRequest`
+        :rtype: :class:`tencentcloud.ckafka.v20190819.models.DescribeRegionResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeRegion", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeRegionResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeRoute(self, request):
         """查看路由信息
 
@@ -698,6 +783,34 @@ class CkafkaClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def FetchMessageByOffset(self, request):
+        """根据指定offset位置的消息
+
+        :param request: Request instance for FetchMessageByOffset.
+        :type request: :class:`tencentcloud.ckafka.v20190819.models.FetchMessageByOffsetRequest`
+        :rtype: :class:`tencentcloud.ckafka.v20190819.models.FetchMessageByOffsetResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("FetchMessageByOffset", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.FetchMessageByOffsetResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ModifyGroupOffsets(self, request):
         """设置Groups 消费分组offset
 
